@@ -2,9 +2,9 @@
 #'
 #' Get data for a single athlete by web scraping, does not require authentication.  
 
-#' @param athl_num numeric athlete id used by Strava
+#' @param athl_num numeric athlete id used by Strava, as character string
 #'
-#' @import RCurl XML xml2
+#' @import XML xml2
 #' 
 #' @concept notoken
 #' 
@@ -13,6 +13,9 @@
 #' @return 	A list with elements for the athlete's information.
 athlind_fun <- function(athl_num){
 	
+	if(any(!is.character(athl_num))) 
+		stop('athl_num must be a character vector')
+	
 	# get unparsed url text using input
 	url_in <- paste0('https://www.strava.com/athletes/', athl_num)
 	
