@@ -22,10 +22,13 @@
 #' stoken <- httr::config(token = strava_oauth(app_name, app_client_id, 
 #' 	app_secret, cache = TRUE))
 #' 
-#' get_gear("g2275365", stoken)
+#' get_gear("2275365", stoken)
 #' }
 get_gear <- function(id, stoken){
 	
+	if(any(!is.character(id)))
+		stop('id must be a character vector')
+	
 	url_ <- url_gear(id)
 	dataRaw <- get_basic(url_, stoken)
 	return(dataRaw)
