@@ -9,7 +9,7 @@
 #' @param act_data an activities list object returned by \code{\link{get_activity_list}}, an \code{actframe} returned by \code{\link{compile_activities}}, or a \code{strfame} returned by \code{\link{get_activity_streams}} 
 #' @param key chr string of Google API key for elevation data, passed to \code{\link[googleway]{google_elevation}} for polyline decoding, see details
 #' @param acts numeric indicating which activities to plot based on index in the activities list, defaults to most recent
-#' @param id optional numeric vector to specify the id(s) of the activity/activities to plot, \code{acts} is ignored if provided
+#' @param id optional character vector to specify the id(s) of the activity/activities to plot, \code{acts} is ignored if provided
 #' @param alpha the opacity of the line desired. A single activity should be 1. Defaults to 0.5
 #' @param add_elev logical indicating if elevation is shown by color shading on the activity lines
 #' @param as_grad logical indicating if elevation is plotted as percent gradient, applies only if \code{add_elev = TRUE}
@@ -64,6 +64,9 @@ get_heat_map <- function(act_data, ...) UseMethod('get_heat_map')
 #' @method get_heat_map list
 get_heat_map.list <- function(act_data, key, acts = 1, id = NULL, alpha = NULL, add_elev = FALSE, as_grad = FALSE, distlab = TRUE, distval = 0, size = 0.5, col = 'red', expand = 10, maptype = 'CartoDB.Positron', zoom = 14, units = 'metric', ...){
 	
+	if(!is.null(id) & any(!is.character(id)))
+		stop('id must be a character vector')
+	
 	# compile
 	act_data <- compile_activities(act_data, acts = acts, id = id, units = units)
 
