@@ -2,7 +2,7 @@
 #' 
 #' Set the url of the athlete to get data using an ID
 #' 
-#' @param id str or integer of athlete id assigned by Strava, NULL will set the authenticated user URL
+#' @param id character of athlete id assigned by Strava, NULL will set the authenticated user URL
 #' 
 #' @export
 #' 
@@ -12,8 +12,14 @@
 url_athlete <- function(id = NULL){
 
 	url_ <- "https://www.strava.com/api/v3/athlete"
-	if(!is.null(id))
+	if(!is.null(id)){
+		
+		if(any(!is.character(id)))
+			stop('id must be a character vector')
+		
 		url_ <- paste(url_,"s/",id, sep = "")
+		
+	}
 	return(url_)
 	
 }
\ No newline at end of file
