@@ -2,7 +2,7 @@
 #' 
 #' Set the url of the clubs for the different requests
 #'
-#' @param id numeric for id of the club, defaults to authenticated club of the athlete
+#' @param id character for id of the club, defaults to authenticated club of the athlete
 #' @param request chr string, must be "members", "activities" or \code{NULL} for club details
 #' 
 #' @details Function is used internally within \code{\link{get_club}}
@@ -16,13 +16,17 @@
 #' @examples
 #' url_clubs()
 #' 
-#' url_clubs(123, request = 'members')
+#' url_clubs('123', request = 'members')
 url_clubs <- function(id = NULL, request = NULL){
 	
 	if(is.null(id)){#Clubs of the authenticated athlete
 		url_ <- paste(url_athlete(), "/clubs", sep = "")
 	}
 	else{ #request must be "members", "activities" or NULL for club details
+		
+		if(any(!is.character(id)))
+			stop('id must be a character vector')
+		
 		url_ <- paste("https://www.strava.com/api/v3/clubs/", id,"/", request, sep = "")
 	}
 	
